import { createRouter, createWebHashHistory } from 'vue-router';
import { useStore } from 'vuex';
const routes = [
  {
    path: '/login',
    name: 'login',
    component: () => import('../views/loggin/loggin.vue')
  },
  {
    path: '/reset',
    name: 'reset',
    component: () => import('../views/loggin/reset.vue'),
    meta: { requiresAuth: false } // 不需要认证

  },
  {
    path: '/',
    name: 'home',
    component: () => import('../views/home/home.vue')
  },
  {
    path: '/recognition',
    name: 'recognition',
    component: () => import('../views/recognize/License-plate-recognition.vue')
  },
  {
    path: '/info',
    name: 'info',
    component: () => import('../views/system-info/info.vue')
  },
  {
    path: '/warning',
    name: 'warning',
    component: () => import('../views/forewarning/forewarning.vue')
  },
  {
    path: '/Footer',
    name: 'Footer',
    component: () => import('../components/Footer.vue')
  },
  {
    path: '/voiceset',
    name: 'voiceset',
    component: () => import('../views/voice/voiceset.vue')
  },
];

const router = createRouter({
  history: createWebHashHistory(), // 使用 hash 模式
  routes
});
router.beforeEach((to, from, next) => {
  const store = useStore(); // 获取 store 实例
  if (to.meta.requiresAuth === false) {
    next(); // 允许访问所有不需要认证的页面
  } else if (to.path !== '/login' && !store.state.isAuthenticated) {
    next('/login'); // 未认证，重定向到登录页面
  } else {
    next(); // 已认证，继续导航
  }
});

export default router;
